summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoPictureImage.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kofficecore/KoPictureImage.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficecore/KoPictureImage.h')
-rw-r--r--lib/kofficecore/KoPictureImage.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/lib/kofficecore/KoPictureImage.h b/lib/kofficecore/KoPictureImage.h
index 98d7d588..4647ba42 100644
--- a/lib/kofficecore/KoPictureImage.h
+++ b/lib/kofficecore/KoPictureImage.h
@@ -21,14 +21,14 @@
#define __koPictureImage_h__
#include "KoPictureBase.h"
-#include <qstring.h>
+#include <tqstring.h>
class KoPictureImagePrivate;
// TODO: fix documentation
/**
* @internal
* KoPictureImage is a container class for a QImage-based picture
* \todo remove private class, as the header is not installed
*/
class KoPictureImage : public KoPictureBase
@@ -65,31 +65,31 @@ public:
* Note that the image is being scaled to that size using scale() - except when printing.
* This avoids scaling the image at each paint event.
*
* The other parameters are very similar to QPainter::drawPixmap :
* (@p x, @p y) define the position in the painter,
* (@p sx, @p sy) specify the top-left point in pixmap that is to be drawn. The default is (0, 0).
* (@p sw, @p sh) specify the size of the pixmap that is to be drawn. The default, (-1, -1), means all the way to the bottom
* right of the pixmap.
*/
- virtual void draw(QPainter& painter, int x, int y, int width, int height, int sx = 0, int sy = 0, int sw = -1, int sh = -1, bool fastMode = false);
+ virtual void draw(TQPainter& painter, int x, int y, int width, int height, int sx = 0, int sy = 0, int sw = -1, int sh = -1, bool fastMode = false);
- virtual QDragObject* dragObject( QWidget *dragSource = 0L, const char *name = 0L );
+ virtual TQDragObject* dragObject( TQWidget *dragSource = 0L, const char *name = 0L );
- virtual bool loadData(const QByteArray& array, const QString& extension);
+ virtual bool loadData(const TQByteArray& array, const TQString& extension);
- virtual bool save(QIODevice* io) const;
+ virtual bool save(TQIODevice* io) const;
- virtual QSize getOriginalSize(void) const;
+ virtual TQSize getOriginalSize(void) const;
- virtual QPixmap generatePixmap(const QSize& size, bool smoothScale = false);
+ virtual TQPixmap generatePixmap(const TQSize& size, bool smoothScale = false);
- virtual QString getMimeType(const QString& extension) const;
+ virtual TQString getMimeType(const TQString& extension) const;
/**
- * Generate a QImage
+ * Generate a TQImage
* (always in slow mode)
*/
- virtual QImage generateImage(const QSize& size);
+ virtual TQImage generateImage(const TQSize& size);
virtual bool hasAlphaBuffer() const
{ return m_originalImage.hasAlphaBuffer(); }
@@ -97,20 +97,20 @@ public:
virtual void setAlphaBuffer(bool enable)
{ m_originalImage.setAlphaBuffer(enable); }
- virtual QImage createAlphaMask(int conversion_flags = 0) const
- { return m_originalImage.createAlphaMask(conversion_flags); }
+ virtual TQImage createAlphaMask(int conversion_flags = 0) const
+ { return m_originalImage.createAlphaMask((Qt::ImageConversionFlags)conversion_flags); }
virtual void clearCache(void);
protected:
- QPixmap getPixmap(QImage& image);
- void scaleAndCreatePixmap(const QSize& size, bool fastMode=false);
+ TQPixmap getPixmap(TQImage& image);
+ void scaleAndCreatePixmap(const TQSize& size, bool fastMode=false);
private:
- QImage m_originalImage; ///< Image as Qimage
- QByteArray m_rawData; ///< Binary copy of the loaded image file
- QPixmap m_cachedPixmap; ///< Cached pixmap
- QSize m_cachedSize; ///< size of the currently cached pixmap @see m_cachedPixmap
+ TQImage m_originalImage; ///< Image as Qimage
+ TQByteArray m_rawData; ///< Binary copy of the loaded image file
+ TQPixmap m_cachedPixmap; ///< Cached pixmap
+ TQSize m_cachedSize; ///< size of the currently cached pixmap @see m_cachedPixmap
/**
* true, if the last cached image was done using fast mode.
* false, if the last cached image was done using slow mode.
@@ -21,14 +21,14 @@
/**
* @internal
- * KoPictureImage is a container class for a QImage-based picture
+ * KoPictureImage is a container class for a TQImage-based picture
* \todo remove private class, as the header is not installed
*/
@@ -65,31 +65,31 @@ public:
* This avoids scaling the image at each paint event.
*
- * The other parameters are very similar to QPainter::drawPixmap :
+ * The other parameters are very similar to TQPainter::drawPixmap :
* (@p x, @p y) define the position in the painter,
* (@p sx, @p sy) specify the top-left point in pixmap that is to be drawn. The default is (0, 0).